PyXMake Developer Guide: PyXMake.VTL.ssh_f2py Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Functions | Variables
PyXMake.VTL.ssh_f2py Namespace Reference

## Functions
def | main (BuildID, user, key, files=VTL.GetSourceCode(0), command=VTL.GetBuildCommand(4), lib=VTL.GetLinkDependency(0, 4,"x64"), source=os.path.join(__mcd_core_path,"src"), include=[posixpath.join(__mcd_cluster_incpath, x) for x in VTL.GetIncludeDirectory(__mcd_core_path, 0, 4, "x64")], dependency=posixpath.join(__mcd_cluster_stable,"lib"), output=posixpath.join(__mcd_cluster_dev,"bin"), environment=VTL.GetEnvironment(2), architecture="x64", scratch=VTL.Scratch, verbosity=2, incremental=False, host="129.247.54.37", port=22)

## Variables
| parser = argparse.ArgumentParser(description="Build shared Fortran libraries for Python remotely on the institute cluster.")
| metavar
| nargs
| help
| args
| user = args.user[0]
| key = args.key[0]
string | BuildID = VTL.GetEnvironment(i)
| files = VTL.GetBuildCommand(4,"free")
list | lib = []
| source = os.path.join(__mcd_core_path,"external","beos")
| command
| include
| dependency
| environment
| env
| verbosity
| incremental

## Detailed Description

    Triple-use minimum working example for PyXMake. This script can be
    executed in three different ways in varying levels of accessibility

    @note: Compile Fortran source for PYTHON remotely
                 on the institute cluster. Uses main function.

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          - PyXMake
          - SSH key

    @date:
          - 24.07.2019

    @author: garb_ma                                      [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

## Function Documentation

## ◆ main()

def PyXMake.VTL.ssh_f2py.main | ( |  | BuildID,
|  |  | user,
|  |  | key,
|  |  | files = `VTL.GetSourceCode(0)`,
|  |  | command = `VTL.GetBuildCommand(4)`,
|  |  | lib = `VTL.GetLinkDependency(0, 4,"x64")`,
|  |  | source = `os.path.join(__mcd_core_path,"src")`,
|  |  | include = `[posixpath.join(__mcd_cluster_incpath, x) for x in VTL.GetIncludeDirectory(__mcd_core_path, 0, 4, "x64")]`,
|  |  | dependency = `posixpath.join(__mcd_cluster_stable,"lib")`,
|  |  | output = `posixpath.join(__mcd_cluster_dev,"bin")`,
|  |  | environment = `VTL.GetEnvironment(2)`,
|  |  | architecture = `"x64"`,
|  |  | scratch = `VTL.Scratch`,
|  |  | verbosity = `2`,
|  |  | incremental = `False`,
|  |  | host = `"129.247.54.37"`,
|  |  | port = `22`
| ) |  |

    Main function to execute the script.

Definition at line 76 of file ssh_f2py.py.